"""Encapsulate prometheus-openstack-exporter testing."""
import unittest

import zaza.model as model


class BasePostfixTest(unittest.TestCase):
    """Base for charm tests."""

    @classmethod
    def setUpClass(cls):
        """Set up tests."""
        super(BasePostfixTest, cls).setUpClass()
        cls.model_name = model.get_juju_model()
        cls.application_name = "postfix-relay"
        cls.lead_unit_name = model.get_lead_unit_name(
            cls.application_name, model_name=cls.model_name
        )
        cls.units = model.get_units(cls.application_name, model_name=cls.model_name)
        cls.Postfix_ip = model.get_app_ips(cls.application_name)[0]


class CharmOperationTest(BasePostfixTest):
    """Verify operations."""

    def test_01_port_open(self):
        """Verify if the port is open."""
        test_command = "/usr/lib/nagios/plugins/check_tcp -H 127.0.0.1 -p 25"
        response = model.run_on_unit(self.lead_unit_name, test_command)

        if response["Code"] == "0":
            return

        # we didn't get rc=0 in the allowed time, fail the test
        self.fail(
            "http port didn't respond to the command \n"
            "'{test_command}' as expected.\n"
            "Result: {result}".format(test_command=test_command, result=response)
        )
        self.assertTrue(response["Code"] == 0)
